<?php

/*
 * Test system for PHP5 classes. Echoes HTML result.
 * Usage:
 *   TestPHP::start("Test Set Name");
 *   TestPHP::test(false, "This test failed");
 *   TestPHP::test(true, "This test passed");
 *   TestPHP::end();
 */
class TestPHP {
	protected static $passed, $failed, $title, $testCount;
	
	/*
	 * Starts the testing
	 */
	public static function start($testSetTitle){
		global $passed,$failed,$testCount,$title;
		
		// Initialize everything
		$passed = array();
		$failed = array();
		$testCount = 0;
		if ($testSetTitle == ""){
			$title = "PHPTester";
		}else{
			$title = $testSetTitle;
		}
	}
	
	/*
	 * Outputs the test results
	 */
	public static function end(){
		echo TestPHP::generateHTML();
	}		

	/*
	 * Evaluates $bool and stores the message and caller info for output
	 */
	public static function test($bool, $msg){
		global $passed,$failed,$testCount;

		// Get the caller info
		$call_info = array_shift( debug_backtrace() );
		$call_line = $call_info['line'];
		$call_file = $call_info['file'];
		$temp = array(	"message"=> (string)$msg,
						"line"	 => (int)$call_line,
						"file"	 => (string)$call_file
		);

		if ($bool == true) {
			// Add the message to the passed test array
			array_push($passed, $temp);
		} else {
			// Add the message to the failed test array
			array_push($failed, $temp);
		}
		$testCount = $testCount + 1;
	}

	/*
	 * Generates and returns HTML test results
	 */	
	private static function generateHTML(){
		global $passed,$failed,$testCount,$title;

		// Make sure tests were run
		if (count($passed) == 0 && count($failed) == 0) {
			return "No tests were run!";
		}
		if ($testCount < 1){
			return "No tests were run!";
		}
		
		$htmlTitle = "PHPTester";
		
		// Output the html header
		$html = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">";
		$html .= "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\"><title>";
		$html .= $htmlTitle . "</title></head><body>";
		
		// Output page heading
		$html .= "<h1>" . $title . "</h1>";
		$html .= "<h2>Ran " . $testCount . " tests. " . count($passed) . " passed and " . count($failed) . " failed.</h2>";
		$html .= "<br>";
		
		// Output the failed tests and their messages
		if (count($failed) > 0){
			$html .= "<h3>Failed Test:</h3>";
			$html .= "<table border=\"1\" width=\"90%\" align=\"center\"><tr><td width=\"20\">File</td><td width=\"20\">Line Number</td><td>Message</td></tr>";
			foreach ($failed as $f){
				$html .= "<tr><td>" . $f["file"] . "</td>";
				$html .= "<td>" . $f["line"] . "</td>";
				$html .= "<td>" . $f["message"] . "</td></tr>";
			}
			$html .= "</table>";		
		}
		
		// Output the passed tests and their messages
		if (count($passed) > 0){
			$html .= "<h3>Passed Test:</h3>";
			$html .= "<table border=\"1\" width=\"90%\" align=\"center\"><tr><td width=\"20\">File</td><td width=\"20\">Line Number</td><td>Message</td></tr>";
			foreach ($passed as $p){
				$html .= "<tr><td>" . $p["file"] . "</td>";
				$html .= "<td>" . $p["line"] . "</td>";
				$html .= "<td>" . $p["message"] . "</td></tr>";
			}
			$html .= "</table>";
		}
		
		// Output the html footer
		$html .= "</body></html>";
		return $html;	
	}
}
?>
